"use strict";Object.defineProperty(exports, "__esModule", {value: true});// index.ts
function resolveOptions(userOptions) {
  const defaultOptions = {
    extensions: ["vue", "md"],
    pagesDir: "pages"
  };
  return Object.assign({}, defaultOptions, userOptions);
}
function isDynamicRoute(routePath) {
  const dynamicRouteRE = new RegExp("^\\[.+\\]$");
  return dynamicRouteRE.test(routePath);
}
function prepareRoutes(routes, options, parent) {
  for (const route of routes) {
    if (route.name)
      route.name = route.name.replace(/-index$/, "");
    if (parent)
      route.path = route.path.replace(/^\//, "").replace(/\?$/, "");
    route.props = true;
    if (route.children) {
      delete route.name;
      route.children = prepareRoutes(route.children, options, route);
    }
    if (typeof (options == null ? void 0 : options.extendRoute) === "function")
      Object.assign(route, options.extendRoute(route, parent) || {});
  }
  return routes;
}
function generateRoutes(filesPath, userOptions) {
  const options = resolveOptions(userOptions);
  const {
    pagesDir,
    extensions
  } = options;
  const extensionsRE = new RegExp(`\\.(${extensions.join("|")})$`);
  const routes = [];
  for (const filePath of Object.keys(filesPath)) {
    const resolvedPath = filePath.replace(extensionsRE, "").replace(`./${pagesDir}/`, "");
    const pathNodes = resolvedPath.split("/");
    const component = filesPath[filePath];
    const route = {
      name: "",
      path: "",
      component
    };
    let parentRoutes = routes;
    for (let i = 0; i < pathNodes.length; i++) {
      const node = pathNodes[i];
      const isDynamic = isDynamicRoute(node);
      const isLastOne = i === pathNodes.length - 1;
      const normalizedPart = (isDynamic ? node.replace(/^\[(\.{3})?/, "").replace(/\]$/, "") : node).toLowerCase();
      route.name += route.name ? `-${normalizedPart}` : normalizedPart;
      const parent = parentRoutes.find((node2) => node2.name === route.name);
      if (parent) {
        parent.children = parent.children || [];
        parentRoutes = parent.children;
        route.path = "";
      } else if (normalizedPart === "index" && !route.path) {
        route.path += "/";
      } else if (normalizedPart !== "index") {
        if (isDynamic) {
          route.path += `/:${normalizedPart}`;
          if (/^\[\.{3}/.test(node))
            route.path += "(.*)";
          else if (isLastOne)
            route.path += "?";
        } else {
          route.path += `/${normalizedPart}`;
        }
      }
    }
    parentRoutes.push(route);
  }
  const preparedRoutes = prepareRoutes(routes, options);
  return preparedRoutes;
}


exports.generateRoutes = generateRoutes;
